@@ -41,7 +41,7 @@ from oauth2 import Request
 #REQUEST_TOKEN_URL = 'https://%(user)s.%(domain)s/oauth/request_token'
 ACCESS_TOKEN_URL = '%(protocol)s://%(user)s.%(domain)s/oauth/access_token'
 #AUTHORIZATION_URL = 'https://%(user)s.%(domain)s/oauth/authorize'
-RESOURCE_URL = '%(protocol)s://%(user)s.%(domain)s/api/v1/sql'
+RESOURCE_URL = '%(protocol)s://%(user)s.%(domain)s/api/%(api_version)s/sql'
 
 
 class CartoDBException(Exception):
@@ -51,8 +51,8 @@ class CartoDBBase(object):
     """ basic client to access cartodb api """
     MAX_GET_QUERY_LEN = 2048
 
-    def __init__(self, cartodb_domain, host='cartodb.com', protocol='https'):
-        self.resource_url = RESOURCE_URL % {'user': cartodb_domain, 'domain': host, 'protocol': protocol}
+    def __init__(self, cartodb_domain, host='cartodb.com', protocol='https', api_version='v1'):
+        self.resource_url = RESOURCE_URL % {'user': cartodb_domain, 'domain': host, 'protocol': protocol, 'api_version': api_version}
 
     def req(self, url, http_method="GET", http_headers=None, body=''):
         """
@@ -88,8 +88,8 @@ class CartoDBOAuth(CartoDBBase):
     """
     This client allows to auth in cartodb using oauth. 
     """
-    def __init__(self, key, secret, email, password, cartodb_domain, host='cartodb.com', protocol='https', proxy_info=None):
-        super(CartoDBOAuth, self).__init__(cartodb_domain, host, protocol)
+    def __init__(self, key, secret, email, password, cartodb_domain, host='cartodb.com', protocol='https', proxy_info=None, *args, **kwargs):
+        super(CartoDBOAuth, self).__init__(cartodb_domain, host, protocol, *args, **kwargs)
 
         self.consumer_key = key
         self.consumer_secret = secret
@@ -129,8 +129,8 @@ class CartoDBAPIKey(CartoDBBase):
     this method is easier than use the oauth authentification but if less secure, it is recommended to use only using the https endpoint
     """
 
-    def __init__(self, api_key, cartodb_domain, host='cartodb.com', protocol='https', proxy_info=None):
-        super(CartoDBAPIKey, self).__init__(cartodb_domain, host, protocol)
+    def __init__(self, api_key, cartodb_domain, host='cartodb.com', protocol='https', proxy_info=None, *args, **kwargs):
+        super(CartoDBAPIKey, self).__init__(cartodb_domain, host, protocol, *args, **kwargs)
         self.api_key = api_key
         self.client = httplib2.Http()
         if protocol != 'https':
